@@ -211,7 +211,7 @@ knitr::include_graphics("./pigFlanking.png")
 #  +             groupColor = c("blue", "red"))
 
 ## ---- fig.retina = NULL, fig.cap="Similarity between Pig and Cow, with added coverage and annotation", echo=FALSE---------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
-knitr::include_graphics("./coverageExample.jpg")
+knitr::include_graphics("./coverageExample.png")
 
 ## ----eval=FALSE-----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
 #  # Load the package
